@@ -1,6 +1,6 @@
 /* ios.h - IO spaces for poke.  */
 
-/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023, 2024 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -23,12 +23,14 @@
 #include <stdint.h>
 #include <stdbool.h>
 
+typedef struct ios_context *ios_context;
+
 /* The following two functions initialize and shutdown the IO poke
    subsystem.  */
 
-void ios_init (void);
+ios_context ios_init (void);
 
-void ios_shutdown (void);
+void ios_shutdown (ios_context ios_ctx);
 
 /* "IO spaces" are the entities used in poke in order to abstract the
    heterogeneous devices that are suitable to be edited, such as
@@ -157,13 +159,14 @@ typedef int64_t ios_off;
    If no IOS_F_READ or IOS_F_WRITE flags are specified, then the IOS
    will be opened in whatever mode makes more sense.  */
 
-int ios_open (const char *handler, uint64_t flags, int set_cur);
+int ios_open (ios_context ios_ctx, const char *handler, uint64_t flags,
+              int set_cur);
 
 /* Close the given IO space, freing all used resources and flushing
    the space cache associated with the space.  Return IOS_OK on success
    and the error code on failure.  */
 
-int ios_close (ios io);
+int ios_close (ios_context ios_ctx, ios io);
 
 /* Return the flags which are active in a given IO.  Note that this
    doesn't necessarily correspond to the flags passed when opening the
@@ -179,33 +182,56 @@ const char *ios_handler (ios io);
 /* Return the current IO space, or NULL if there are no open
    spaces.  */
 
-ios ios_cur (void);
+ios ios_cur (ios_context ios_ctx);
 
 /* Set the current IO space to IO.  */
 
-void ios_set_cur (ios io);
+void ios_set_cur (ios_context ios_ctx, ios io);
 
-/* Return the IO space operating the given HANDLER.  Return NULL if no
-   such space exists.  */
+/* Return the IO space operating the given non-empty HANDLER.  Based on
+   the FLAGS search use different strategies for matching the HANDLER.
+   Return NULL if no such space exists.  */
 
-ios ios_search (const char *handler);
+/* Bit 0 choose exact/partial search strategies.  Other bits can change
+   the interpretation of this bit in the future.  */
+#define IOS_SEARCH_F_EXACT 0
+#define IOS_SEARCH_F_PARTIAL 1
+
+ios ios_search (ios_context ios_ctx, const char *handler, uint32_t flags);
 
 /* Return the IO space having the given ID.  Return NULL if no such
    space exists.  */
 
-ios ios_search_by_id (int id);
+ios ios_search_by_id (ios_context ios_ctx, int id);
 
 /* Return the ID of the given IO space.  */
 
 int ios_get_id (ios io);
 
+/* Return the handler of the given IO space.  */
+
+const char *ios_get_handler (ios io);
+
 /* Return the name of the device interface.  */
 
 const char *ios_get_dev_if_name (ios io);
 
+/* Return the IO device interface implementing the IO devices operated by
+   the given IO space.
+
+   Please keep this in-sync with declarations in `libpoke/ios-dev.h'.  */
+
+const struct ios_dev_if *ios_get_dev_if (ios ios);
+
+/* Return the IO device instance operated by the given IO space.
+
+   Please keep this in-sync with declarations in `libpoke/ios-dev.h'.  */
+
+void *ios_get_dev (ios ios);
+
 /* Return the first IO space.  */
 
-ios ios_begin (void);
+ios ios_begin (ios_context ios_ctx);
 
 /* Return the space following IO.  */
 
@@ -219,7 +245,7 @@ bool ios_end (const ios io);
 
 typedef void (*ios_map_fn) (ios io, void *data);
 
-void ios_map (ios_map_fn cb, void *data);
+void ios_map (ios_context ios_ctx, ios_map_fn cb, void *data);
 
 /* **************** IOS properties************************  */
 
@@ -238,6 +264,8 @@ ios_off ios_get_bias (ios io);
 
 void ios_set_bias (ios io, ios_off bias);
 
+int ios_zombie_p (ios io);
+
 /* **************** Object read/write API ****************  */
 
 /* An integer with flags is passed to the read/write operations,
@@ -354,7 +382,7 @@ int ios_flush (ios io, ios_off offset);
    If no forereign IO device is registered, return NULL.
    Otherwise return a pointer to the interface.  */
 
-struct ios_dev_if *ios_foreign_iod (void);
+struct ios_dev_if *ios_foreign_iod (ios_context ios_ctx);
 
 /* Register a foreign IO device.
 
@@ -364,6 +392,15 @@ struct ios_dev_if *ios_foreign_iod (void);
    Return IOS_OK otherwise.  */
 
 struct ios_dev_if;
-int ios_register_foreign_iod (struct ios_dev_if *iod_if);
+int ios_register_foreign_iod (ios_context ios_ctx,
+                              struct ios_dev_if *iod_if, void *data);
+
+/* **************** Sub IO space **************** */
+
+/* Increase the number of sub-devices for IOS.  */
+void ios_inc_sub_dev (ios io);
+
+/* Decrease the number of sub-devices for IOS.  */
+void ios_dec_sub_dev (ios io);
 
 #endif /* ! IOS_H */
