@@ -115,55 +115,52 @@ extern int pkl_tab_debug;
     FORMAT = 308,                  /* "keyword `format'"  */
     COMPUTED = 309,                /* "keyword `computed'"  */
     IMMUTABLE = 310,               /* IMMUTABLE  */
-    BUILTIN_TERM_GET_COLOR = 311,  /* BUILTIN_TERM_GET_COLOR  */
-    BUILTIN_TERM_SET_COLOR = 312,  /* BUILTIN_TERM_SET_COLOR  */
-    BUILTIN_TERM_GET_BGCOLOR = 313, /* BUILTIN_TERM_GET_BGCOLOR  */
-    BUILTIN_TERM_SET_BGCOLOR = 314, /* BUILTIN_TERM_SET_BGCOLOR  */
-    POWA = 315,                    /* "power-and-assign operator"  */
-    MULA = 316,                    /* "multiply-and-assign operator"  */
-    DIVA = 317,                    /* "divide-and-assing operator"  */
-    MODA = 318,                    /* "modulus-and-assign operator"  */
-    ADDA = 319,                    /* "add-and-assing operator"  */
-    SUBA = 320,                    /* "subtract-and-assign operator"  */
-    SLA = 321,                     /* "shift-left-and-assign operator"  */
-    SRA = 322,                     /* "shift-right-and-assign operator"  */
-    BANDA = 323,                   /* "bit-and-and-assign operator"  */
-    XORA = 324,                    /* "bit-xor-and-assign operator"  */
-    IORA = 325,                    /* "bit-or-and-assign operator"  */
-    RANGEA = 326,                  /* "range separator"  */
-    OR = 327,                      /* "logical or operator"  */
-    AND = 328,                     /* "logical and operator"  */
-    IMPL = 329,                    /* "logical implication operator"  */
-    EQ = 330,                      /* "equality operator"  */
-    NE = 331,                      /* "inequality operator"  */
-    LE = 332,                      /* "less-or-equal operator"  */
-    GE = 333,                      /* "bigger-or-equal-than operator"  */
-    SL = 334,                      /* "left shift operator"  */
-    SR = 335,                      /* "right shift operator"  */
-    CEILDIV = 336,                 /* "ceiling division operator"  */
-    POW = 337,                     /* "power operator"  */
-    BCONC = 338,                   /* "bit-concatenation operator"  */
-    NSMAP = 339,                   /* "non-strict map operator"  */
-    INC = 340,                     /* "increment operator"  */
-    DEC = 341,                     /* "decrement operator"  */
-    AS = 342,                      /* "cast operator"  */
-    ISA = 343,                     /* "type identification operator"  */
-    ATTR = 344,                    /* "attribute"  */
-    UNMAP = 345,                   /* "unmap operator"  */
-    REMAP = 346,                   /* "remap operator"  */
-    EXCOND = 347,                  /* "conditional on exception operator"  */
-    BIG = 348,                     /* "keyword `big'"  */
-    LITTLE = 349,                  /* "keyword `little'"  */
-    SIGNED = 350,                  /* "keyword `signed'"  */
-    UNSIGNED = 351,                /* "keyword `unsigned'"  */
-    THREEDOTS = 352,               /* "varargs indicator"  */
-    THEN = 353,                    /* THEN  */
-    UNARY = 354,                   /* UNARY  */
-    HYPERUNARY = 355,              /* HYPERUNARY  */
-    START_EXP = 356,               /* START_EXP  */
-    START_DECL = 357,              /* START_DECL  */
-    START_STMT = 358,              /* START_STMT  */
-    START_PROGRAM = 359            /* START_PROGRAM  */
+    POWA = 311,                    /* "power-and-assign operator"  */
+    MULA = 312,                    /* "multiply-and-assign operator"  */
+    DIVA = 313,                    /* "divide-and-assing operator"  */
+    MODA = 314,                    /* "modulus-and-assign operator"  */
+    ADDA = 315,                    /* "add-and-assing operator"  */
+    SUBA = 316,                    /* "subtract-and-assign operator"  */
+    SLA = 317,                     /* "shift-left-and-assign operator"  */
+    SRA = 318,                     /* "shift-right-and-assign operator"  */
+    BANDA = 319,                   /* "bit-and-and-assign operator"  */
+    XORA = 320,                    /* "bit-xor-and-assign operator"  */
+    IORA = 321,                    /* "bit-or-and-assign operator"  */
+    RANGEA = 322,                  /* "range separator"  */
+    OR = 323,                      /* "logical or operator"  */
+    AND = 324,                     /* "logical and operator"  */
+    IMPL = 325,                    /* "logical implication operator"  */
+    EQ = 326,                      /* "equality operator"  */
+    NE = 327,                      /* "inequality operator"  */
+    LE = 328,                      /* "less-or-equal operator"  */
+    GE = 329,                      /* "bigger-or-equal-than operator"  */
+    SL = 330,                      /* "left shift operator"  */
+    SR = 331,                      /* "right shift operator"  */
+    CEILDIV = 332,                 /* "ceiling division operator"  */
+    POW = 333,                     /* "power operator"  */
+    BCONC = 334,                   /* "bit-concatenation operator"  */
+    NSMAP = 335,                   /* "non-strict map operator"  */
+    INC = 336,                     /* "increment operator"  */
+    DEC = 337,                     /* "decrement operator"  */
+    AS = 338,                      /* "cast operator"  */
+    ISA = 339,                     /* "type identification operator"  */
+    IND = 340,                     /* "indirection operator"  */
+    ATTR = 341,                    /* "attribute"  */
+    UNMAP = 342,                   /* "unmap operator"  */
+    REMAP = 343,                   /* "remap operator"  */
+    EXCOND = 344,                  /* "conditional on exception operator"  */
+    BIG = 345,                     /* "keyword `big'"  */
+    LITTLE = 346,                  /* "keyword `little'"  */
+    SIGNED = 347,                  /* "keyword `signed'"  */
+    UNSIGNED = 348,                /* "keyword `unsigned'"  */
+    THREEDOTS = 349,               /* "varargs indicator"  */
+    THEN = 350,                    /* THEN  */
+    UNARY = 351,                   /* UNARY  */
+    HYPERUNARY = 352,              /* HYPERUNARY  */
+    START_EXP = 353,               /* START_EXP  */
+    START_DECL = 354,              /* START_DECL  */
+    START_STMT = 355,              /* START_STMT  */
+    START_PROGRAM = 356            /* START_PROGRAM  */
   };
   typedef enum pkl_tab_tokentype pkl_tab_token_kind_t;
 #endif
@@ -172,7 +169,7 @@ extern int pkl_tab_debug;
 #if ! defined PKL_TAB_STYPE && ! defined PKL_TAB_STYPE_IS_DECLARED
 union PKL_TAB_STYPE
 {
-#line 373 "pkl-tab.y"
+#line 370 "pkl-tab.y"
 
   pkl_ast_node ast;
   struct
@@ -185,7 +182,7 @@ union PKL_TAB_STYPE
   int integer;
   char *exception_msg;
 
-#line 189 "pkl-tab.h"
+#line 186 "pkl-tab.h"
 
 };
 typedef union PKL_TAB_STYPE PKL_TAB_STYPE;
