@@ -1,6 +1,6 @@
 /* pkl-trans.c - Transformation phases for the poke compiler.  */
 
-/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023, 2024 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -1530,6 +1530,7 @@ PKL_PHASE_BEGIN_HANDLER (pkl_trans1_ps_asm_stmt)
       ass_stmt = pkl_ast_make_ass_stmt (PKL_PASS_AST,
                                         output,
                                         NULL /* exp */);
+      PKL_AST_LOC (ass_stmt) = PKL_AST_LOC (asm_stmt);
       /* Note the reverse order.  */
       assignments = pkl_ast_chainon (ass_stmt, assignments);
     }
@@ -1689,8 +1690,7 @@ PKL_PHASE_END_HANDLER
    Also, struct references that refer to parameterless methods are
    transformed into funcalls to these methods, but only if the struct
    references are not part of funcall themselves.  This is similar to
-   what is done with variable nodes. */
-
+   what is done with variable nodes.  */
 
 PKL_PHASE_BEGIN_HANDLER (pkl_trans2_ps_struct_ref)
 {
@@ -1800,6 +1800,7 @@ PKL_PHASE_BEGIN_HANDLER (pkl_trans2_ps_incrdecr)
       PKL_AST_TYPE (exp_plus_one) = ASTREF (incrdecr_exp_type);
       ass_stmt = pkl_ast_make_ass_stmt (PKL_PASS_AST,
                                         incrdecr_exp, exp_plus_one);
+      PKL_AST_LOC (ass_stmt) = PKL_AST_LOC (incrdecr);
 
       PKL_AST_INCRDECR_ASS_STMT (incrdecr) = ASTREF (ass_stmt);
       PKL_PASS_RESTART = 1;
@@ -1973,7 +1974,7 @@ PKL_PHASE_BEGIN_HANDLER (pkl_trans3_ps_op_sizeof)
 
     offset_type = pkl_ast_make_offset_type (PKL_PASS_AST,
                                             PKL_AST_TYPE (magnitude),
-                                            unit);
+                                            unit, NULL /* ref_type */);
     PKL_AST_TYPE (offset) = ASTREF (offset_type);
   }
 
