@@ -1,6 +1,6 @@
 /* pk-cmd-set.c - Commands to show and set properties.  */
 
-/* Copyright (C) 2019, 2020, 2021, 2022, 2023 Jose E. Marchesi */
+/* Copyright (C) 2019, 2020, 2021, 2022, 2023, 2024 Jose E. Marchesi */
 
 /* This program is free software: you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -41,20 +41,9 @@ pk_cmd_set_dump (int argc, struct pk_cmd_arg argv[], uint64_t uflags)
       || exit_exception != PK_NULL)
     PK_UNREACHABLE (); /* This shouldn't happen.  */
 
-#if HAVE_HSERVER
-  {
-    char *hyperlink;
-
-    hyperlink = pk_hserver_make_hyperlink ('e', ".help error-on-warning", PK_NULL);
-    pk_term_hyperlink (hyperlink, NULL);
-  }
-#endif
-
+  pk_term_class ("setting-header");
   pk_puts ("error-on-warning");
-
-#if HAVE_HSERVER
-  pk_term_end_hyperlink ();
-#endif
+  pk_term_end_class ("setting-header");
   pk_printf (" %s\n", pk_error_on_warning (poke_compiler) ? "yes" : "no");
 
   return 0;
@@ -80,7 +69,7 @@ pk_cmd_set (int int_p,
       assert (registry_get != PK_NULL);
 
       if (pk_call (poke_compiler, registry_get, &retval, &exit_exception,
-                   2, pk_make_string (setting_name), registry)
+                   2, pk_make_string (poke_compiler, setting_name), registry)
           == PK_ERROR
           || exit_exception != PK_NULL)
         /* This shouldn't happen.  */
@@ -98,16 +87,16 @@ pk_cmd_set (int int_p,
       const char *retmsg;
 
       if (int_p)
-        val = pk_make_int (PK_CMD_ARG_INT (argv[1]), 32);
+        val = pk_make_int (poke_compiler, PK_CMD_ARG_INT (argv[1]), 32);
       else
-        val = pk_make_string (PK_CMD_ARG_STR (argv[1]));
+        val = pk_make_string (poke_compiler, PK_CMD_ARG_STR (argv[1]));
 
       registry_set = pk_struct_ref_field_value (registry, "set");
       assert (registry_set != PK_NULL);
 
-      if (pk_call (poke_compiler, registry_set, &retval, &exit_exception,
-                   3, pk_make_string (setting_name), val, registry)
-          == PK_ERROR
+      if (pk_call (poke_compiler, registry_set, &retval, &exit_exception, 3,
+                   pk_make_string (poke_compiler, setting_name), val, registry)
+              == PK_ERROR
           || exit_exception != PK_NULL)
         /* This shouldn't happen, since we know `newval' is of the
            right type.  */
@@ -217,7 +206,7 @@ extern struct pk_cmd null_cmd; /* pk-cmd.c  */
 
 const struct pk_cmd set_error_on_warning_cmd =
   {"error-on-warning", "s?", "", 0, NULL, NULL, pk_cmd_set_error_on_warning,
-   "set error-on-warning (yes|no)", yesno_completion_function};
+   ".set error-on-warning (yes|no)", yesno_completion_function};
 
 const struct pk_cmd **set_cmds;
 
